# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MgmtSshKey',
]

@pulumi.output_type
class MgmtSshKey(dict):
    def __init__(__self__, *,
                 name: str,
                 type: str,
                 comment: Optional[str] = None,
                 key: Optional[str] = None):
        """
        :param str name: Name of SSH key.
        :param str type: Type of SSH key, e.g. ssh-rsa.
        :param str comment: Comment.
        :param str key: Public SSH key.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of SSH key.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of SSH key, e.g. ssh-rsa.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def comment(self) -> Optional[str]:
        """
        Comment.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        Public SSH key.
        """
        return pulumi.get(self, "key")


